@@ -23,11 +23,11 @@ class Database:
           try:
             self.db = sqlite3.connect(self.path)
             self.cursor = self.db.cursor()
-            
+
           except:
             print 'Database doesn t exist'
             self._create()
-            
+
           self._update()
 
         def _create(self):
@@ -46,9 +46,8 @@ class Database:
           self.cursor.execute('SELECT version From db_struct;')
           for version in self.cursor.fetchall():
             v = version
-            
+
           version = v[0]
-          print version
           if version < '0.1.0':
             self._create()
           if version < '0.1.1':
@@ -65,7 +64,7 @@ class mPrefs:
        def __init__(self):
            self.hpane_position = None
            self.load_from_db()
-         
+
        def load_from_db(self):
            db = Database(DB_PATH)
            db.cursor.execute('SELECT uuid, value FROM prefs')
@@ -74,10 +73,9 @@ class mPrefs:
                self.hpane_position=int(prefs[1])
            db.close()
 
-           print self.hpane_position
            if self.hpane_position==None:
              self.save_to_db()
-             
+
        def save_to_db(self):
            db = Database(DB_PATH)
            if self.hpane_position==None:
@@ -161,7 +159,7 @@ class NotesList:
             db.close()
 
             return self.notes_list
-            
+
         def get_notes_with_text(self,text):
             db = Database(DB_PATH)
 
@@ -174,7 +172,5 @@ class NotesList:
               note = Note(uuid[0])
               self.notes_list.append((note.title,note.uuid))
             db.close()
-            print 'search results'
-            print self.notes_list
 
             return self.notes_list
