@@ -22,15 +22,14 @@ class mNotes(object):
 
   __pretty_app_name__ = "mNotes"
   __app_name__ = "mNotes"
-  __version__ = "0.1.1"
+  __version__ = "0.1.2"
   __context__ = "net.khertan.mnotes"
 
   _glade_files = [
-    'ui/mnotes.glade',
+    '/usr/lib/mnotes/ui/mnotes.glade',
   ]
 
   def __init__(self,app,context):
-    print 'start init'
     self._callbackList = None
     self._search_text = None
 
@@ -82,7 +81,7 @@ class mNotes(object):
     self._widgetTree.signal_autoconnect(callbackMapping)
 
     self._load_hpane_position()
-    
+
     if self._window:
       self._children_color_bg(self._window)
       self._window.connect("delete-event", self._win_closebox)
@@ -98,15 +97,14 @@ class mNotes(object):
       start, end = buffer.get_bounds ()      
       self._current_note.description = buffer.get_text(start,end)
       self._current_note.save_to_db()
-      
+
       if (self._current_selection_iter):
         uuid = self._notesList.set_value(self._current_selection_iter, 1,self._current_note.title)
-              
+
       self.refresh()
       #self._load_noteslist_bg()
 
   def _row_selected(self,widget,*args):
-    print 'row_selected'
     selection = self.notesListTree.get_selection()
     model, selection_iter = selection.get_selected()
 
@@ -114,23 +112,18 @@ class mNotes(object):
       uuid = self._notesList.get_value(selection_iter, 0)
       self._save_current_note()
       self._current_selection_iter = selection_iter
-      print 'row selected load : ' + uuid
       self._current_note = mnotes_framework.Note(uuid)
       self._editor.get_buffer().set_text(self._current_note.description)
     return
-    
+
   def _search_note(self,widget):
     self._search_text = self._widgetTree.get_widget("SearchTexte").get_text()
     self._load_noteslist_bg()
-    print 'end _search_note'
-    
 
   def _delete_note(self,widget):
-    print 'delete'
     selection = self.notesListTree.get_selection()
     model, selection_iter = selection.get_selected()
     if (selection_iter):
-      print 'Why,,?'
       uuid = self._notesList.get_value(selection_iter, 0)
       note = mnotes_framework.Note(uuid)
       self._notesList.remove(selection_iter)
@@ -139,54 +132,11 @@ class mNotes(object):
       self.notesListTree.set_cursor(0)
       selection.select_path(0)
       self.refresh()  
-      
 
   def refresh(self):
-#   gtk.gdk.threads_enter()
-    print 'start refresh'
-#    return True
-    
-    #Save selection
-#    uuid = None
-#    selection = self.notesListTree.get_selection()
-#    model, selection_iter = selection.get_selected()
-#    if (selection_iter):
-#      uuid = self._notesList.get_value(selection_iter, 0)
-    
-#    if (self._search_text==None) or (self._search_text==''):
-#      notes_list =  mnotes_framework.NotesList().get_all_notes()
-#    else:
-#      notes_list =  mnotes_framework.NotesList().get_notes_with_text(self._search_text)
-#    notes_list.sort()
-#    new_order = range(len(notes_list))
-#    uuid_list = []
-##    pos = 0
-##    sel = 0
-#    for note in notes_list:
-#      #if note[0]==uuid:
-##        sel=pos
-#      uuid_list.append(note[1])
-##      pos=pos+1
-#
-#    iter = self._notesList.get_iter_root()
-#    index = 0
-#    while(iter):
-#      new_order[uuid_list.index(self._notesList.get_value(iter, 0))] = index
-#      index = index  + 1
-#      iter = self._notesList.iter_next(iter)
-#    self._notesList.reorder(new_order)
     self._pijama_color()
-    
-    #Restore selection
-#    selection = self.notesListTree.get_selection()
-#    selection.unselect_all()
-#    selection.select_path(sel)
-    
-    print 'end refresh'
 
   def _pijama_color(self):
-    #pijama
-#   gtk.gdk.threads_enter()
     iter = self._notesList.get_iter_root()
     pij = True
     while(iter):
@@ -200,7 +150,6 @@ class mNotes(object):
     self.notesListTree.queue_draw()
 
   def _add_note(self,widget):
-    print 'add note'
     self._save_current_note()
     note = mnotes_framework.Note('')
     self._notesList_append(self._notesList,note.uuid,note.title,note.get_fg_color(),note.get_bg_color(),note.get_style())
@@ -211,19 +160,17 @@ class mNotes(object):
     self.notesListTree.set_cursor(len(self._notesList)-1)
     self.refresh()
     self.notesListTree.queue_draw()
-    
+
   def _save_hpane_position(self):
-    print 'savepref'
     value = self._widgetTree.get_widget("hpaned1").get_position()
     prefs = mnotes_framework.mPrefs()
     prefs.hpane_position = value
     prefs.save_to_db()
 
   def _load_hpane_position(self):
-    print 'loadpref'
     value = mnotes_framework.mPrefs().hpane_position
     self._widgetTree.get_widget("hpaned1").set_position(value)
-    
+
   def _win_closebox(self,widget,data):
     self._save_current_note()
     self._save_hpane_position()
@@ -257,7 +204,6 @@ class mNotes(object):
 
     self._editor = self._widgetTree.get_widget("Editor")
     self._editor.get_buffer().set_text('Welcome to mnotes !')
-    self._editor.get_buffer().connect ('changed', self.on_modified)
 
     self.notesListTree = self._widgetTree.get_widget("Liste")
     self.notesListTree.set_grid_lines(False)
@@ -290,8 +236,6 @@ class mNotes(object):
     self.create_menu()
     gtk.gdk.threads_leave()
 
-    print 'end idle'
-
     return False
 
   def _on_window_state_change(self, widget, event, *args):
@@ -312,14 +256,9 @@ class mNotes(object):
     self._notes_loader_process = threading.Thread(target=self._load_noteslist,args=[self._notesList])
     self._notes_loader_process.start()
 
-  def on_modified(self,data):
-    print 'on_modified'
-#    self._save_current_note()
-
   def _load_noteslist(self,notesList):
     gtk.gdk.threads_enter()
     notesList.clear()
-    print 'load_noteslist :'+str(self._search_text)
     if (self._search_text==None) or (self._search_text==''):
       notes_uuid_list =  mnotes_framework.NotesList().get_all_notes()
     else:
